@@ -15,13 +15,13 @@
     template <typename NewType, typename ...Types>
     struct Append<TypeList<Types...>, NewType>
     {
-        typedef TypeList<Types..., NewType> List;
+        using List = TypeList<Types..., NewType>;
     };
 
     template <typename NewType, typename ...Types>
     struct Prefix<NewType, TypeList<Types...>>
     {
-        typedef TypeList<NewType, Types...> List;
+        using List = TypeList<NewType, Types...>;
     };
 //=
 
