@@ -8,7 +8,7 @@
         template <typename T>
         struct Basic
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = false,
@@ -21,7 +21,7 @@
         template <typename T>
         struct Basic<T const>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = true,
@@ -34,7 +34,7 @@
         template <typename T>
         struct Basic<T *>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = true,
@@ -48,7 +48,7 @@
         template <typename T>
         struct Basic<T const *>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = true,
@@ -61,7 +61,7 @@
         template <typename T>
         struct Basic<T &>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = false,
@@ -74,7 +74,7 @@
         template <typename T>
         struct Basic<T const &>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = false,
@@ -86,7 +86,7 @@
         template <typename T>
         struct Basic<T &&>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = false,
@@ -98,7 +98,7 @@
         template <typename T>
         struct Basic<T const &&>
         {
-            typedef T Type;
+            using Type = T;
             enum
             {
                 isPointer = false,
@@ -111,10 +111,10 @@
         public:
             BasicTraits(BasicTraits const &other) = delete;
 
-            typedef typename Basic<TypeParam>::Type ValueType;
-            typedef ValueType *PtrType;
-            typedef ValueType &RefType;
-            typedef ValueType &&RvalueRefType;
+            using ValueType = typename Basic<TypeParam>::Type;
+            using PtrType = ValueType *;
+            using RefType = ValueType &;
+            using RvalueRefType = ValueType &&;
 
             enum
             {
