@@ -4,13 +4,13 @@ struct Remove;
 template<typename Rm>
 struct Remove<TypeList<Rm>>                 // empty list
 {
-    typedef TypeList<> Removed;
+    using Removed = TypeList<>;
 };
 
 template<typename Rm, typename ...Tail>     // remove Rm fm the head,
 struct Remove<TypeList<Rm, Rm, Tail...>>
 {
-    typedef typename Remove<TypeList<Rm, Tail...>>::Removed Removed;
+    using Removed = typename Remove<TypeList<Rm, Tail...>>::Removed;
 };
 
                                             // keep First, rm Rm from Tail
@@ -18,7 +18,6 @@ struct Remove<TypeList<Rm, Rm, Tail...>>
 template<typename Rm, typename First, typename ...Tail>
 struct Remove<TypeList<Rm, First, Tail...>>
 {
-    typedef TypeList<First,
-        typename Remove<TypeList<Rm, Tail...>>::Removed
-                    > Removed;
+    using Removed = TypeList<First,
+        typename Remove<TypeList<Rm, Tail...>>::Removed>;
 };
