@@ -19,7 +19,7 @@ class Filter
 
 
 struct Convert      // if there's just one ReturnType operator()(...), simply
-{                   // define  `typedef ReturnType type'
+{                   // specify   `using type = ReturnType'
     template <typename Signature>
     struct result;
 
@@ -30,7 +30,7 @@ struct Convert      // if there's just one ReturnType operator()(...), simply
     template <typename Class>
     struct result<Class(int)>
     {
-        typedef double type;
+        using type = double;
     };
 
     string operator()(double x) const
@@ -40,7 +40,7 @@ struct Convert      // if there's just one ReturnType operator()(...), simply
     template <typename Class>
     struct result<Class(double)>
     {
-        typedef string type;
+        using  type = string;
     };
 };
 
