@@ -3,23 +3,23 @@
     template <typename Iterator>
     struct iterator_types
     {
-        typedef typename Iterator::pointer           pointer;
-        typedef typename Iterator::reference         reference;
+        using pointer = Iterator::pointer;
+        using reference = Iterator::reference;
     };
 */
     template <typename T>
-    struct iterator_types //<T*>
+    struct iterator_types //<T *>
     {
-        typedef T*                         pointer;
-        typedef T&                         reference;
+        using pointer = T *;
+        using reference = T &;
     };
 
     template <typename Iterator>
     class reverse_iter
     {
         public:
-            typedef typename iterator_types<Iterator>::pointer     pointer;
-            typedef typename iterator_types<Iterator>::reference   reference;
+            using pointer = iterator_types<Iterator>::pointer;
+            using reference = iterator_types<Iterator>::reference;
 
             explicit reverse_iter(Iterator x)
             :
@@ -27,8 +27,7 @@
             {}
             reference operator*() const
             {
-                Iterator
-                    tmp = current;
+                Iterator tmp = current;
                 return (*--tmp);
             }
             pointer operator->() const
@@ -42,8 +41,7 @@
             }
             reverse_iter<Iterator> operator++(int)
             {
-                reverse_iter<Iterator>
-                    tmp(current--);
+                reverse_iter<Iterator> tmp(current--);
                 return (tmp);
             }
             bool operator!=(reverse_iter<Iterator> const &other)
@@ -57,8 +55,8 @@
     template <typename Type>
     class Vector
     {
-        typedef Type *iterator;
-        typedef reverse_iter<iterator> reverse_iterator;
+        using iterator = Type *;
+        using reverse_iterator = reverse_iter<iterator>;
 
         public:
             Vector()
