@@ -3,5 +3,5 @@
 void Parser::reset()
 {
     d_rpn.clear();
-    d_rpn.str(string());
+    d_rpn.str(""s);
 }
