@@ -14,11 +14,11 @@
         public:
             OFdnStreambuf() = default;
             OFdnStreambuf(int fd, size_t bufsize = 1);
-            virtual ~OFdnStreambuf();
+            ~OFdnStreambuf() override;
             void open(int fd, size_t bufsize = 1);
         private:
-            virtual int sync();
-            virtual int overflow(int c);
+            int sync() override;
+            int overflow(int c) override;
     };
 //=
 
