@@ -14,9 +14,9 @@
         char   *d_base;
         public:
             FdUnget(int fd, size_t bufsz, size_t unget);
-            virtual ~FdUnget();
+            ~FdUnget() override;
         private:
-            int underflow();
+            int underflow() override;
     };
 //=
 //CONS
