@@ -7,7 +7,7 @@ using namespace FBB;
 //MAIN
     int main()
     {
-        fistream fis(cin);
+        Fistream fis(cin);
 
         fis >> hex;
         while (true)
@@ -16,7 +16,7 @@ using namespace FBB;
             switch (x = fis.get())
             {
                 case '\n':
-                    cout << endl;
+                    cout << '\n';
                 break;
                 case '+':
                     cout << ' ';
