@@ -1,13 +1,14 @@
     #include <iostream>
     #include <istream>
-    #include <unistd.h>
     #include "ifdbuf.h"
     using namespace std;
 
-    int main(int argc)
+//MAIN
+    int main()
     {
-        ifdstreambuf fds(STDIN_FILENO);
+        IFdStreambuf fds(STDIN_FILENO);
         istream      is(&fds);
 
         cout << is.rdbuf();
     }
+//=
