@@ -1,9 +1,15 @@
     #include <iterator>
 
-    class RandomIterator:
-          public std::iterator<std::random_access_iterator_tag, int>
+    struct RandomIterator
     {
-        int d_value;
+        using iterator_category = std::bidirectional_iterator_tag;
+        using difference_type   = std::ptrdiff_t;
+        using value_type        = int;
+        using pointer           = value_type *;
+        using reference         = value_type &;
+
+        private:
+            int d_value;
 
         public:
             RandomIterator(int init);
