@@ -15,7 +15,7 @@
         };
         multimap<string, int> object(&pa[0], &pa[6]);
 
-        typedef multimap<string, int>::iterator msiIterator;
+        using msiIterator = multimap<string, int>::iterator;
 
         msiIterator it = object.lower_bound("brava");
 
