@@ -6,12 +6,12 @@ class [[nodiscard]] Generator
 {
     friend class Promise<T>;
 
-    typedef std::coroutine_handle<Promise<T>> Handle;
+    using Handle = std::coroutine_handle<Promise<T>>;
 
     Handle d_handle = 0;
 
     public:
-        typedef Promise<T> promise_type;
+        using promise_type = Promise<T>;
 
         Generator() noexcept = default;
 
