@@ -4,7 +4,7 @@ class RecGenIterator
     Promise *d_promise = 0;
 
     public:
-        typedef std::conditional_t<std::is_reference_v<T>, T, T&> Reference;
+        using Reference = std::conditional_t<std::is_reference_v<T>, T, T &>;
 
         RecGenIterator() noexcept = default;
 
