@@ -11,7 +11,7 @@
 //writer
 struct Writer
 {
-    typedef std::optional<std::string> ValueType;
+    using ValueType = std::optional<std::string>;
 
     private:
         class State: public PromiseBase<Writer, State>
@@ -27,7 +27,7 @@ struct Writer
         std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Writer(std::coroutine_handle<State> handle);
         ~Writer();
