@@ -15,8 +15,7 @@
 
         // Note: the comparisons are: "mike" > word[i]
         replace_copy_if(words, words + size, result,
-                        bind1st(greater<string>(), string("mike")),
-                        string("ALPHA"));
+                        bind1st(greater<string>(), "mike"s), "ALPHA"s);
         copy (result, result + size, ostream_iterator<string>(cout, " "));
         cout << '\n';
     }
