@@ -15,7 +15,6 @@
                           "oscar", "papa", "quebec" };
         string set2[] = { "papa", "quebec", "romeo"};
         string result[7];
-        string *returned;
 
         copy(result,
             set_intersection(set1, set1 + 7, set2, set2 + 3, result),
@@ -30,8 +29,6 @@
             ostream_iterator<string>(cout, " "));
         cout << '\n';
     }
-    /*
-        Displays:
-            papa quebec
-            papa quebec
-    */
+    //  Displays:
+    //      papa quebec
+    //      papa quebec
