@@ -12,9 +12,9 @@
         {
             cin >> x;
         }
-        catch(ios::failure failure)
+        catch (ios::failure failure)
         {
-            cout << "Here's what: " << failure.what() << endl;
+            cout << "Here's what: " << failure.what() << '\n';
         }
     }
     /*
