@@ -1,7 +1,5 @@
     #include <iostream>
-    #include <string>
     #include <sstream>
-    #include <fstream>
 
     using namespace std;
 
@@ -9,23 +7,32 @@
     {
         ostringstream ostr("hello ", ios::ate);
 
-        cout << ostr.str() << endl;
+        cout << ostr.str() << '\n';
 
         ostr.setf(ios::showbase);
         ostr.setf(ios::hex, ios::basefield);
         ostr << 12345;
 
-        cout << ostr.str() << endl;
+        cout << ostr.str() << '\n';
 
         ostr << " -- ";
         ostr.unsetf(ios::hex);
         ostr << 12;
 
-        cout << ostr.str() << endl;
+        cout << ostr.str() << '\n';
+
+        ostr.str("new text");
+        cout << ostr.str() << '\n';
+
+        ostr.seekp(4, ios::beg);
+        ostr << "world";
+        cout << ostr.str() << '\n';
     }
     /*
         Output from this program:
     hello
     hello 0x3039
     hello 0x3039 -- 12
+    new text
+    new world
     */
