@@ -8,7 +8,7 @@ int main()
     char buffer[3 * sizeof(string)];
     string *sp = new(buffer) string [3];
 
-    for (size_t idx = 0; idx < 3; ++idx)
+    for (size_t idx = 0; idx != 3; ++idx)
         sp[idx].~string();
 //=
 }
