@@ -7,12 +7,12 @@ int main()
 {
     Math math;
 
-    cout << math.count() << "\n"
+    cout << "Initial number of additions: " << math.count() << "\n"
             "Enter two pos. values to add: ";
 
     size_t lhs;
     size_t rhs;
     cin >> lhs >> rhs;
     cout << "their sum is " << math.add(lhs, rhs) << "\n"
-            "total count: " << math.count() << '\n';
+            "total number of performed additions: " << math.count() << '\n';
 }
