@@ -41,11 +41,18 @@
         return operatorIndex(index);
     }
 
-    int IntArray::operator[](size_t index) const
+    int const &IntArray::operator[](size_t index) const
     {
         return operatorIndex(index);
     }
 
+    void IntArray::swap(IntArray &other)
+    {
+        // swaps the d_size and d_data data members
+        // of *this and other
+    }
+
+
     void IntArray::boundary(size_t index) const
     {
         if (index < d_size)
