@@ -8,7 +8,7 @@
         public:
             Fatal(std::string  const &reason);
         private:
-            virtual void action() const;
+            void action() const override;
     };
 
     inline Fatal::Fatal(std::string  const &reason)
