@@ -9,16 +9,10 @@
         int iArr[] = { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10};
 
         cout << count_if(iArr, iArr + 10, bind2nd(less_equal<int>(), 6)) <<
-            endl;
+            ' ';
         cout << count_if(iArr, iArr + 10, bind2nd(not2(greater<int>()), 6)) <<
-            endl;
+            ' ';
         cout << count_if(iArr, iArr + 10, not1(bind2nd(greater<int>(), 6))) <<
-            endl;
+            '\n';
     }
-    /*
-        produced output:
-
-        6
-        6
-        6
-    */
+    // Displays: 6 6 6
