@@ -14,7 +14,7 @@
     };
     int main()
     {
-        unique_ptr<int *, Deleter<int *, 10>> sp2(new int *[10]);
+        unique_ptr<int *, Deleter<int *, 10>> sp2(new int *[10]());
 
-        Deleter<int *, 10> &obj = sp2.get_deleter();
+        [[maybe_unused]] Deleter<int *, 10> &obj = sp2.get_deleter();
     }
