@@ -17,7 +17,7 @@ std::future<void> asyncCall(char const *label)
 
 int main()
 {
-    asyncCall("First")
+    asyncCall("First");
     asyncCall("Second");
 }
 //=
