@@ -5,7 +5,7 @@ void newTask(string const &line)
 {
     Task task{ line, PackagedTask(compile) };
 
-    pushResultQ(task.result());
+    pushResultQ(task.result());             // the results are in the resultQ
     g_taskQ.push(move(task));
 }
 //=
