@@ -7,7 +7,11 @@ void partition(Pair const &range)
         return;
 
     auto rhsBegin = partition(range.first + 1, range.second,
-                            bind2nd(less<int>(), *range.first));
+                                  [=](int value)
+                                  {
+                                      return value < *range.first;
+                                  }
+                              );
     auto lhsEnd = rhsBegin - 1;
 
     swap(*range.first, *lhsEnd);
